==> camel-base-3.4.5-sources.jar: org/apache/camel/impl/event/CamelContextStartupFailureEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl.event;

import org.apache.camel.CamelContext;
import org.apache.camel.spi.CamelEvent;

public class CamelContextStartupFailureEvent extends AbstractContextEvent implements CamelEvent.CamelContextStartupFailureEvent {
    private static final long serialVersionUID = -4271899927507894567L;

    private Throwable cause;

    public CamelContextStartupFailureEvent(CamelContext context, Throwable cause) {
        super(context);
        this.cause = cause;
    }

    @Override
    public Throwable getCause() {
        return cause;
    }

    @Override
    public String toString() {
        return "Failed to start Camel: " + getContext().getName() + " due to " + cause.getMessage();
    }
}

==> camel-base-4.4.0-sources.jar: org/apache/camel/impl/event/CamelContextStartupFailureEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl.event;

import org.apache.camel.CamelContext;
import org.apache.camel.spi.CamelEvent;

public class CamelContextStartupFailureEvent extends AbstractContextEvent
        implements CamelEvent.CamelContextStartupFailureEvent {
    private static final long serialVersionUID = -4271899927507894567L;

    private final Throwable cause;

    public CamelContextStartupFailureEvent(CamelContext context, Throwable cause) {
        super(context);
        this.cause = cause;
    }

    @Override
    public Throwable getCause() {
        return cause;
    }

    @Override
    public String toString() {
        return "CamelContext startup failure: " + getContext().getName() + " due to " + cause.getMessage();
    }
}
